@@ -95,7 +95,6 @@ sub main{
 
   my $phylip = mashDistance($sketches,\@reads,$$settings{tempdir},$settings);
 
-  logmsg "Creating a NJ tree with BioPerl";
   my $treeObj = createTreeFromPhylip($phylip,$$settings{tempdir},$settings);
 
   print $treeObj->as_text('newick');
@@ -239,6 +238,7 @@ sub mashSketch{
       logmsg "WARNING: ".basename($fastq)." was already mashed.";
     } elsif(-s $fastq < 1){
       logmsg "WARNING: $fastq is a zero byte file. Skipping.";
+      next;
     } else {
       logmsg "Sketching $fastq";
       system("mash sketch -p $$settings{cpus_per_mash} -k $$settings{kmerlength} -s $$settings{'sketch-size'} $sketchXopts -o $outPrefix $fastq  1>&2");
@@ -290,9 +290,10 @@ sub mashDistance{
     $thr[$_]=threads->new(\&mashDist,$outdir,$threadArr[$_],$mshListFilename,$mashtreeDbFilename,$settings);
   }
 
-  logmsg "Joining $$settings{numthreads} threads";
   for(@thr){
+    logmsg "Waiting to join thread TID".$_->tid;
     my $distfiles=$_->join;
+    logmsg "Joined TID".$_->tid;
   }
 
   my $phylip = "$outdir/distances.phylip";
